# attrs

```
usage: attrs [-h] [-a] [path] [attr [attr ...]]

List attributes or look at one attribute

positional arguments:
  path        Path to object whose attributes to check
  attr        Any number of attributes to check. If none are given, show the
              names of all available attributes. If one is given, show the
              value of that attribute. If several are given, show the values
              for all of those attributes, in recfile-like format.

optional arguments:
  -h, --help  show this help message and exit
  -a, --all   Show all attribute values, in recfile-like format
```
